@@ -102,6 +102,27 @@ def rpl(code=13):
     return [int(x) for x in d[0]["timeSeries"][1]["areas"][0]["pops"]][:4]
 
 
+def wi():
+    """
+    東京の気温と湿度から，洗濯指数を得る。
+    """
+    tokyo_humid = humid()
+    temp_f = temp()
+    temp_c = f2c(temp_f)
+    wi = 0.01*tokyo_humid
+    wi = wi*(0.99*temp_c-14.3)
+    wi = wi+0.81*temp_c+46.3
+    return wi
+
+
+def wr_index():
+    """
+    東京の今日の天気を，インデックスで返す
+    1:晴れ，2:曇り，3:雨，4:雪
+    """
+    return int(d[0]["timeSeries"][0]["areas"][0]["weatherCodes"][0][0])
+
+
 def get_eq_info():
     dc_url = "https://api.p2pquake.net/v2/jma/quake?limit=1"
     resp = requests.get(dc_url)
