@@ -350,6 +350,12 @@ button {
             cd();
             setTimeout(cd, 1000);
             setTimeout(cd, 2000);
+
+            var button1 = document.getElementById('button'),
+                button2 = document.getElementById('button2');
+            button1.disabled = true;
+            button2.disabled = true;
+
         };
 
 	</script>
