@@ -62,11 +62,9 @@ def rb(timings):
         elif isinstance(timings[0], str):
             timing_list = [[], [], [], []]
             for ti, ts in enumerate(timings):
-                print(ts)
                 for i, s in enumerate(ts):
                     if s == "1":
                         timing_list[ti].append(i)
-            print(timing_list)
             show_frame(timing_list, 8, 4)
 
     elif isinstance(timings, str):
@@ -81,7 +79,6 @@ def rb2(timing_str_list):
         for n, s in enumerate(words):
             if s in timing_str[i].lower():
                 timings[n].append(i)
-    print(timings)
     show_frame(timings, 8, 4)
 
 
